@@ -104,7 +104,8 @@ def a_credits():
     print("\
 === Credits ==\n\
 Thank you to the repl.it community for providing such amazing services for free.\n\
-Thank you to Atticus Kuhn for poiting out safety concerns on the project.\n\
+Thank you to Atticus Kuhn for pointing out safety concerns on the project.\n\
+Thank you to AmazingMech2418 (https://repl.it/@AmazingMech2418), for showing me the world of cryptography.\
 Thank you StealthHydra179 (https://repl.it/@StealthHydra179), for being the only person who cared about programming in my school.\n\
 Thank you Giothecoder (https://repl.it/@Giothecoder), for being there when I needed you most.")
 
